'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.directive = undefined;

var _utils = require('./utils');

var RulesMessage = {
  name: 'RulesMessage',
  functional: true,
  props: {
    type: {
      type: String
    },
    selector: {
      type: String
    },
    match: {
      type: Boolean,
      default: false
    },
    parentClassError: {
      type: String,
      default: 'has-error'
    },
    message: {
      type: String
    }
  },
  render: function render(h, _ref) {
    var parent = _ref.parent,
        props = _ref.props;

    var errorIndex = (0, _utils.findIndexForActiveError)(parent.rulesErrors, props.type, props.match);
    var isActive = errorIndex >= 0;
    var elementToMatch = props.selector || props.type;
    if (parent.$el && parent.$el.querySelector) {
      var inputParent = parent.$el.querySelector('#' + elementToMatch);
      if (inputParent && isActive) {
        inputParent.classList.add(props.parentClassError);
      } else if (inputParent && !isActive) {
        inputParent.classList.remove(props.parentClassError);
      }
    }
    if (isActive) {
      var propsData = {
        class: 'error',
        attrs: {
          id: props.type + '-rule-error'
        }
      };
      parent.product = parent.product || 'general';
      var parentName = parent.$options.name || parent.$options._componentTag;
      var parentKeyWP = parentName + '.ruleErrors.' + parent.product.toLowerCase() + '.' + parent.rulesErrors[errorIndex];
      var parentKey = parentName + '.ruleErrors.' + parent.rulesErrors[errorIndex];
      var keyWP = 'ruleErrors.' + parent.product.toLowerCase() + '.' + parent.rulesErrors[errorIndex];
      var key = 'ruleErrors.' + parent.rulesErrors[errorIndex];
      var translation = props.message ? props.message : !parent.$i18n ? parentKeyWP : parent.$i18n.t(parentKeyWP) !== parentKeyWP ? parent.$i18n.t(parentKeyWP) : parent.$i18n.t(parentKey) !== parentKey ? parent.$i18n.t(parentKey) : parent.$i18n.t(keyWP) !== keyWP ? parent.$i18n.t(keyWP) : parent.$i18n.t(key) !== key ? parent.$i18n.t(key) : parent.$i18n.t(parentKeyWP);
      return h('span', propsData, [translation]);
    } else {
      return null;
    }
  }
};

var directive = exports.directive = {
  bind: function bind(el, binding, vnode) {
    var validateRules = vnode.context.validateRules;
    var name = binding.value;
    if (!validateRules || !name) {
      return;
    }
    vnode.context.$watch(name, function (newValue, oldValue) {
      if (newValue !== oldValue) {
        validateRules();
      }
    });
  }
};

RulesMessage.install = function (Vue) {
  Vue.component(RulesMessage.name, RulesMessage);
  Vue.directive('rule-validate', directive);
};

exports.default = RulesMessage;