'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.regex = exports.isEmail = exports.compareFields = exports.required = exports.maxLength = exports.minLength = undefined;

var _lodash = require('lodash.get');

var _lodash2 = _interopRequireDefault(_lodash);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var emailRegex = /[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+(?:[A-Z]{2}|com|org|net|gov|mil|biz|info|mobi|name|aero|jobs|museum)\b/;

var minLength = exports.minLength = function minLength(path, errorType, minimun) {
  var defaultValue = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';

  return function (state) {
    var value = (0, _lodash2.default)(state, path, defaultValue) || defaultValue;
    return (0, _utils.factoryValidationObj)(value.length >= minimun, errorType);
  };
};

var maxLength = exports.maxLength = function maxLength(path, errorType, max) {
  var defaultValue = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';

  return function (state) {
    var value = (0, _lodash2.default)(state, path, defaultValue) || defaultValue;
    return (0, _utils.factoryValidationObj)(value.length <= max, errorType);
  };
};

var required = exports.required = function required(path, errorType) {
  return function (state) {
    return (0, _utils.factoryValidationObj)((0, _lodash2.default)(state, path), errorType);
  };
};

var compareFields = exports.compareFields = function compareFields(path, errorType, otherFieldPath) {
  return function (state) {
    var fieldOne = (0, _lodash2.default)(state, path);
    var fieldTwo = (0, _lodash2.default)(state, otherFieldPath);
    return (0, _utils.factoryValidationObj)(fieldOne === fieldTwo, errorType);
  };
};

var isEmail = exports.isEmail = function isEmail(path, errorType, notUsed) {
  var defaultValue = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';

  return function (state) {
    var value = (0, _lodash2.default)(state, path, defaultValue) || defaultValue;
    return (0, _utils.factoryValidationObj)(emailRegex.test(value), errorType);
  };
};

var regex = exports.regex = function regex(path, errorType, expresion) {
  var defaultValue = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';

  return function (state) {
    var value = (0, _lodash2.default)(state, path, defaultValue) || defaultValue;
    return (0, _utils.factoryValidationObj)(expresion.test(value), errorType);
  };
};